@@ -7,9 +7,9 @@ use warnings;
 use Exporter 'import';
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-11-23'; # DATE
+our $DATE = '2023-11-24'; # DATE
 our $DIST = 'Set-Streak'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 our @EXPORT_OK = qw(gen_longest_streaks_table);
 
@@ -39,7 +39,7 @@ For example, let's generate a table for longest daily CPAN releases for November
 The result of the routine will be like:
 
     [
-      {item=>"PERLANCAR", start=>1, len=>5, status=>"ongoing"},
+      { item => "PERLANCAR", len => 5, start => 1, status => "ongoing" },
       { item => "SREZIC", len => 3, start => 2, status => "might-break" },
       { item => "JGNI", len => 3, start => 3, status => "ongoing" },
       { item => "JRM", len => 2, start => 4, status => "ongoing" },
@@ -60,6 +60,7 @@ MARKDOWN
         },
         exclude_broken => {
             summary => 'Whether to exclude broken streaks',
+            schema => 'bool*',
             description => <<'MARKDOWN',
 
 Streak status is either: `ongoing` (item still appear in current period),
@@ -83,7 +84,7 @@ sub gen_longest_streaks_table {
 
     my $sets = $args{sets};
 
-    my %streaks; # list of all streaks, key="<period>.<item name>", value=[length, broken in which period]
+    my %streaks; # list of all streaks, key="<starting period>.<item name>", value=[length, broken in which period]
   FIND_STREAKS: {
         my $period = 0;
         my %current_items; # items with streaks currently going, key=item, val=starting period
@@ -101,7 +102,7 @@ sub gen_longest_streaks_table {
             } # FIND_NEW
 
 
-            # find broken streaks: items that no longer appears in this period
+            # find broken streaks: items that no longer appear in this period
           FIND_BROKEN: {
                 for my $item (keys %current_items) {
                     my $key = $current_items{$item} . "." . $item;
@@ -166,7 +167,7 @@ sub gen_longest_streaks_table {
 }
 
 1;
-# ABSTRACT: Routines related to streaks (longest appearance in consecutive sets)
+# ABSTRACT: Routines related to streaks (longest item appearance in consecutive sets)
 
 __END__
 
@@ -176,11 +177,11 @@ __END__
 
 =head1 NAME
 
-Set::Streak - Routines related to streaks (longest appearance in consecutive sets)
+Set::Streak - Routines related to streaks (longest item appearance in consecutive sets)
 
 =head1 VERSION
 
-This document describes version 0.002 of Set::Streak (from Perl distribution Set-Streak), released on 2023-11-23.
+This document describes version 0.003 of Set::Streak (from Perl distribution Set-Streak), released on 2023-11-24.
 
 =head1 FUNCTIONS
 
@@ -212,7 +213,7 @@ For example, let's generate a table for longest daily CPAN releases for November
 The result of the routine will be like:
 
  [
-   {item=>"PERLANCAR", start=>1, len=>5, status=>"ongoing"},
+   { item => "PERLANCAR", len => 5, start => 1, status => "ongoing" },
    { item => "SREZIC", len => 3, start => 2, status => "might-break" },
    { item => "JGNI", len => 3, start => 3, status => "ongoing" },
    { item => "JRM", len => 2, start => 4, status => "ongoing" },
@@ -231,7 +232,7 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<exclude_broken> => I<any>
+=item * B<exclude_broken> => I<bool>
 
 Whether to exclude broken streaks.
 
